## **Sports Biomechanics**

**[ISSN: (Print) (Online) Journal homepage: https://www.tandfonline.com/loi/rspb20](https://www.tandfonline.com/loi/rspb20)**

# **Measuring maximal horizontal deceleration ability** **using radar technology: reliability and sensitivity** **of kinematic and kinetic variables**

**Damian J. Harper, Jean-Benoit Morin, Christopher Carling & John Kiely**

**To cite this article:** Damian J. Harper, Jean-Benoit Morin, Christopher Carling & John
Kiely (2020): Measuring maximal horizontal deceleration ability using radar technology:
reliability and sensitivity of kinematic and kinetic variables, Sports Biomechanics, DOI:
[10.1080/14763141.2020.1792968](https://www.tandfonline.com/action/showCitFormats?doi=10.1080/14763141.2020.1792968)

**To link to this article:** [https://doi.org/10.1080/14763141.2020.1792968](https://doi.org/10.1080/14763141.2020.1792968)

Published online: 31 Jul 2020.

[Submit your article to this journal](https://www.tandfonline.com/action/authorSubmission?journalCode=rspb20&show=instructions)

Article views: 6

[View related articles](https://www.tandfonline.com/doi/mlt/10.1080/14763141.2020.1792968)

[View Crossmark data](http://crossmark.crossref.org/dialog/?doi=10.1080/14763141.2020.1792968&domain=pdf&date_stamp=2020-07-31)

Full Terms & Conditions of access and use can be found at
[https://www.tandfonline.com/action/journalInformation?journalCode=rspb20](https://www.tandfonline.com/action/journalInformation?journalCode=rspb20)

SPORTS BIOMECHANICS

<https://doi.org/10.1080/14763141.2020.1792968>

### **Measuring maximal horizontal deceleration ability using** **radar technology: reliability and sensitivity of kinematic and** **kinetic variables**

Damian J. Harper a, Jean-Benoit Morin b, Christopher Carling c and John Kiely a

aInstitute of Coaching and Performance, School of Sport and Health Sciences, University of Central
Lancashire, Preston, UK; \[b\] Laboratory of Human Motricity, Expertise in Sports and Health, Faculty of Sports
Science, Côte d’Azur University, Nice, France; \[c\] Centre for Elite Performance, French Football Federation,
Paris, France

**ABSTRACT**
Radar technology has the potential for providing new insights into
maximal horizontal deceleration ability. This study aimed to inves­
tigate the intra- and inter-day reliability and sensitivity of kinematic
and kinetic variables obtained from a novel, maximal horizontal
deceleration test, using radar technology. Thirty-eight university
sport athletes completed testing for intra-day analysis. Twelve of
these participants also completed the deceleration test on a ­
second day for inter-day analysis. The maximal horizontal decelera­
tion test required participants to decelerate maximally following
20 m maximal horizontal sprint acceleration. Reliability was
assessed using the intraclass correlation coefficient (ICC) and coeffi­
cient of variation (CV%). Sensitivity was evaluated by comparing
typical error (TE) to the smallest worthwhile change (SWC).
A number of kinematic and kinetic variables had good (ICC > 0.75,
CV \< 10%) overall intra-day reliability, and were sensitive to detect
small-to-moderate changes in deceleration performance after
a single familiarisation session. Only kinetic variables had good
overall inter-day reliability and were sensitive to detect moderate
changes in deceleration performance. The utilisation of this test
protocol to assess maximal horizontal deceleration can provide
new insights into individual maximal horizontal deceleration cap­
abilities. Future work using this or similar approaches may provide
insights into the neuromuscular performance qualities needed to
decelerate maximally.

**Introduction**

**ARTICLE HISTORY**

Received 2 October 2019
Accepted 1 July 2020

**KEYWORDS**
Braking; velocity; force;
power; impulse; profiling

Within competitive team sports contexts players must frequently and rapidly change
velocity to dynamically adapt to evolving technical and tactical game demands. Such
velocity changes can be positive (acceleration) or negative (deceleration), with both
considered to be critical components of match-play performance. As illustrated in
team sports such as soccer, players typically perform between 16–39 high-intensity
accelerations (>3 m/s \[2\] ) and 43–59 high-intensity decelerations (\<-3 m/s \[2\] ) per match

**CONTACT** Damian J. Harper <DJHarper@uclan.ac.uk>

© 2020 Informa UK Limited, trading as Taylor & Francis Group

2 D. J. HARPER ET AL.

(De Hoyo et al., 2016; Russell et al., 2016; Tierney et al., 2016). Furthermore, during the
most demanding passages of play, players typically perform between 6.4 and 7.9 highintensity accelerations and decelerations per minute (Martín-García et al., 2018).
Consequently, the capacity to profile individual players’ maximal horizontal sprint
acceleration and deceleration abilities, and subsequently apply these insights to inform
the design of performance enhancement and injury prevention strategies, may be highly
beneficial within team sports environments.

Sprint accelerations have been extensively researched, providing new insights into the
technical and mechanical capabilities needed to accelerate rapidly (Colyer et al., 2018;
Cross et al., 2017). Subsequently, training interventions targeting specific components of
acceleration, such as the capacity to generate a greater horizontal component of ground
reaction force, have been designed and practically implemented (Morin & Samozino,
2016; Morin et al., 2011, 2015). Crucially, however, far fewer investigations have docu­
mented the player’s ability to decelerate rapidly. As such, there is substantially less
available evidence capable of informing training strategies targeting the development
of rapid deceleration capabilities (Harper & Kiely, 2018). This is problematic for sports
science and medical professionals working with team sport athletes, where high-intensity
decelerations are typically performed more frequently than high-intensity accelerations,
and also inflict more negative consequences than equivalently intense accelerations
(Harper et al., 2019).

Indeed, in comparison to accelerations, rapid decelerations impose higher mechanical
loads during match play (Dalen et al., 2016) and result in a ground reaction force profile
with significantly higher impact peaks and loading rates (Verheul et al., 2019). As such,
there is an exacerbated risk of tissue damage and the likelihood of injury occurrence
(Howatson & Milak, 2009; Keane et al., 2015). Hence, the development of superior
acceleration capabilities, if not accompanied by concurrently improving deceleration
capabilities, could potentially lead to performance deficiencies in tasks that demand rapid
decelerations from high approach velocities (Loturco et al., 2019). Accordingly, protocols
capable of comprehensively and accurately profiling a player’s ability to rapidly decele­
rate may provide important diagnostic information to help inform and guide perfor­
mance enhancement and injury prevention training strategies.

Radar and laser devices are recommended for profiling horizontal sprint acceleration
capabilities (Nagahara et al., 2017). Such devices could also be beneficially employed to
profile maximal horizontal decelerations in more detail than previously possible
(Simperingham et al., 2016). For example, commonly estimated mechanical outputs,
such as horizontal force and power, can be derived for sprint accelerations by applying
simple computational methods based on Newtonian principles applied to the centre of
mass (Morin et al., 2019). Such metrics, potentially, provide valuable insights into the
mechanical capabilities needed to decelerate rapidly. Only a small number of studies,
however, have attempted to assess horizontal deceleration (Ashton & Jones, 2019; Cesar
& Sigward, 2015, 2016; Graham-Smith et al., 2018; Harper et al., 2018; Naylor & Greig,
2015). Furthermore, only one of these studies examined the reliability and sensitivity of
a laser device to measure maximal horizontal deceleration abilities (Ashton & Jones,
2019). However, this study only reported deceleration distances measured at 75%, 50%,
25% and 0% of the players maximal 15 m sprint velocity. Importantly, the trial-to-trial
variability (measurement error) for all four of these variables was large (CV >10%),

SPORTS BIOMECHANICS 3

making it difficult to detect small but meaningful changes in horizontal deceleration
ability. The authors suggested that these large CV values could be due to inter-trial
differences in when, and where, athletes commenced their decelerations. Consequently, it
is feasible that regulating the velocity at which decelerations commence, as per previous
work investigating maximal horizontal deceleration abilities (Harper et al., 2018), could
improve the reliability and sensitivity of collated deceleration data.

Therefore, the aim of this study was to determine the intra- and inter-day reliability
and sensitivity of radar-derived kinematic and kinetic measurements, obtained during
maximal horizontal decelerations from a regulated running velocity. It was hypothesised
that a range of kinematic and kinetic variables would have good (ICC > 0.75, CV \<10%)
overall intra- and inter-day reliability, and would be sufficiently sensitive to detect smallto-moderate changes in deceleration performance.

**Methods**

_**Participants**_

Thirty-eight university sport athletes ( _n_ = 29 male, _n_ = 9 female, age: 19.7 ± 1.7 years,
height: 176 ± 10 cm, body mass: 73.0 ± 14.7 kg) engaging primarily in team sports
(soccer, rugby league, rugby union, netball) volunteered to participate. The eligibility
criteria specified, that for inclusion in the study, all participants had to be regularly
partaking (3 times per week) in moderate- to high-intensity exercise, and be familiar with
change of direction (COD) tasks requiring high-intensity accelerations and decelerations.
Participants who had suffered musculoskeletal injury, that had prevented participation in
sport or physical activity within the previous 3 months, were excluded. Testing was
conducted mid-way through the UK University competitive sport season. All partici­
pants completed testing on day 1 (intra-day analysis), whilst twelve participants
( _n_ = 8 male, _n_ = 4 female, age: 19.4 ± 1.5 years, height: 175 ± 10 cm, body mass:
74.4 ± 14.3 kg) also completed testing on day 2 (inter-day analysis). The institutional
ethics review committee at the University of Central Lancashire granted ethical approval.
All participants were provided with a written information sheet that explained the
requirements of the study and the benefits and risks of participation. Participants were
also given opportunity to ask any questions before providing voluntary informed written

consent.

_**Experimental design**_

A within-subject repeated measures research design was used to determine the intra- and
inter-test reliability of kinetic and kinematic variables obtained from a new test of
maximal horizontal deceleration measuring using radar technology. All experimental
procedures took place over a 2-week period, in which participants were required to
complete 3 testing sessions with at least 48 hours recovery between. In the first test
session, all participants had anthropometric measurements taken and completed a 20 m
horizontal sprint. They were then familiarised with the protocols of the maximal hor­
izontal deceleration test. Familiarisation involved participants firstly observing
a demonstration of the maximal horizontal deceleration test. Following this, all

4 D. J. HARPER ET AL.

participants practised the deceleration test following a progressive increase in intensity
(70%, 80%, 100% perceived effort). In the subsequent two sessions, participants com­
pleted the maximal horizontal deceleration test to allow determination of intra- and
inter-test reliability. Prior to all testing participants completed the same 15-minute
standardised warm-up that included forwards and backwards jogging, dynamic stretch­
ing, and 3 practice trials of the deceleration test following a progressive increase in
intensity (70%, 80% and 100% perceived effort). To reduce the potential influence of
confounding variables all sessions were completed at the same time of the day (9:00am to
12:00pm) on an indoor artificial sports surface. Furthermore, the same accredited sport
and exercise scientist administered all test instructions, and measurements, and con­
ducted subsequent data analysis.

_**Procedures**_

_**Anthropometrics**_
Standing height was measured to the nearest cm using a stadiometer (Seca 217,
Hamburg, Germany), and body mass to the nearest 0.1 kg using electronic weighing
scales (Seca, Hamburg, Germany).

_**Maximal horizontal sprint test**_
Sprint times were recorded over 20 m distance using timing gates (Witty, Microgate,
Bolzano, Italy) set to a height of 0.8 m (Cronin & Templeton, 2008). Times were recorded
to the nearest 0.01 s. Each sprint commenced from a stationary split stance position with
the front foot positioned 30 cm behind the timing gate to prevent a false trigger.
Participants were instructed to initiate their own start with no backwards step or ‘rocking
motion’ and to sprint as fast as possible. Each participant was allowed 2 trials interspersed
by a passive recovery period of at least a 2-minute duration. The best 20 m split was used
as a ‘criterion’ time in the maximal horizontal deceleration test.

_**Maximal horizontal deceleration test**_

Maximal horizontal deceleration was assessed using an acceleration-deceleration ability
(ADA) test (Harper et al., 2018). Participants were instructed to use the same start protocol
employed for the horizontal sprint test and to sprint maximally over 20 m before perform­
ing a maximal horizontal deceleration. The 20 m point marking the start of the deceleration
phase was identified with tall marker poles. Immediately following the end of the decelera­
tion, players backpedalled to the 20 m line. This created a clear change in velocity on the
instantaneous velocity-time graph captured by the radar device and enabled the end of the
deceleration phase to be easily identified (Figure 1). To ensure the start of the deceleration
commenced as close to the 20 m point as possible, any 20 m time that was 5% greater than
the best 20 m split time achieved during the horizontal sprint test was considered as an
unsuccessful trial. In such cases, the participant was asked to repeat the test following at
least a 3-minute recovery period. Participants were asked to perform a maximum of five
trials, with the two successful trials with the highest average deceleration used for analysis.

Instantaneous horizontal velocity was measured throughout all phases of the test using
a radar device (Stalker ATS II, Applied Concepts, Inc., Dallas, TX, USA) sampling at 47 Hz,
which was connected to a laptop with the Stalker ATS system software (Version 5.0,

SPORTS BIOMECHANICS 5

Applied Concepts, Inc., Dallas, TX, USA) for data acquisition. To enable instantaneous
horizontal velocity to be recorded whilst participant was moving away (acceleration and
deceleration phases) and towards (back-pedal to signify the end of deceleration phase) the
radar, the target direction setting on the radar was set to ‘both’. The radar device was
mounted on a heavy-duty tripod and positioned 5 m behind the start line, which is within
the 4.6 to 9.6 m distance recommended by the manufacturer for recording acceleration and
braking run tests. The radar device was set to a height 1 m above the ground to approxi­
mately align with the participant’s centre of mass. When the participant was in the
stationary start position, data recording was started using the ‘any key’ feature of the
Stalker ATS system software, and a verbal instruction of ‘when you are ready’ provided
to the participant. Data capture was ended using the ‘any key’ feature once the participant
had backpedalled to the 20 m line following the maximal horizontal deceleration.

**Figure 1.** Acceleration-deceleration ability (ADA) test layout used to assess players maximal horizontal
deceleration ability.

_**Data analysis**_
All data were manually processed in the graph mode editor of the Stalker ATS software
following similar procedures outlined by Simperingham et al. (2019) for horizontal forcevelocity-power profiling during short sprint-running acceleration. This involved: (i)
deleting all data recorded before the start of the sprint and following the end of the
deceleration phase, (ii) nominating all trials to be ‘acceleration runs’ thereby forcing the
start of the velocity–time curve through the zero point, (iii) applying a digital fourthorder, zero-lag Butterworth filter (as recommended by the manufacturer), and (iii)
manually removing unexpected high and low data points on the velocity–time curve
that were likely caused by segmental movements of the participants while sprinting. Once
manual processing had been completed instantaneous horizontal velocity ( _v_ ), time ( _t_ )
and distance ( _d_ ) for each trial was exported to Microsoft Excel for further analyses.

6 D. J. HARPER ET AL.

The start of the deceleration phase was defined as the time point immediately following
the maximum velocity (Vmax) achieved during the 20 m sprint. The end of the deceleration
phase was defined as the lowest velocity (Vlow) following Vmax. The deceleration phase was
also further divided into early and late deceleration phases by using the time point
associated with 50% Vmax (Figure 2).

**Deceleration Phase**

DECEarly DECLate

9

8

7

6

5

4

3

2

1

vlow

0

| Col1 | Col2 | Col3 | Col4 | vmax | 50% vmax | Col7 |
| ---- | ---- | ---- | ---- | ---- | -------- | ---- |
|      |      |      |      |      |          |      |

0.0 0.5 1.0 1.5 2.0 2.5 3.0 3.5 4.0 4.5

**Time (s)**

**Figure 2.** Example of velocity-time profile showing deceleration phase following manual processing with
Stalker ATS™ system software. _V_ max = maximum velocity defining start of deceleration phase; 50% _V_ max
= 50% of maximal velocity separating early and late deceleration phases; _Vlow_ = lowest velocity defining
end of deceleration phase; DECEarly = early deceleration phase representing time between _V_ max and
50% _V_ max; DECLate = late deceleration phase representing time between 50% _V_ max and _V_ low.

Instantaneous horizontal deceleration was calculated between each data point cap­
tured across the entire deceleration phase using the following equation:

_Deceleration m_ � _=s_ \[2\] �

¼ _\[v\]\[f\]_ \[ �\] _\[v\]\[i\]_

� �

_\[v\]\[f\]_ \[ �\] _\[v\]\[i\]_

(1)
~~�~~ _tf_ � _ti_ ~~�~~

where _v_ is the velocity, _t_ is the time, _f_ is the final velocity or time, and _i_ is the initial
velocity or time.

Kinematic variables analysed included: (1) average deceleration (DECave; average of all
instantaneous deceleration values calculated from start to end of deceleration phase), (2)
maximum deceleration (DECmax; highest instantaneous deceleration value calculated between

SPORTS BIOMECHANICS 7

start and end of deceleration phase), (3) early-deceleration (E-DEC; average of all instanta­
neous deceleration values calculated between the start of deceleration phase to 50%
Vmax), (4) late deceleration (L-DEC; an average of all instantaneous deceleration values
calculated between 50% Vmax and end of deceleration phase), (5) time to stop (TTS; time
taken from start to end of deceleration phase), (6) time to 50% Vmax (TT50%Vmax; time taken
from the start of the deceleration phase to 50% Vmax) and (7) distance to stop (DTS; distance
travelled from start to end of deceleration phase).

Kinetic variables estimated in the deceleration phase included average horizontal braking
force (HBFave), braking power (HBPave) and braking impulse (HBIave) calculated using the
average of all instantaneous HBF, HBI and HBP values obtained from start to end of
deceleration. Also estimated were the average HBF, HBP and HBI during the early and late
deceleration phases using instantaneous values obtained between the start of deceleration and
50% Vmax, and 50% Vmax and end of deceleration, respectively. Maximal HBF, HBP and HBI
were calculated using the highest instantaneous value between the start and end of the
deceleration phase.

Instantaneous HBF was calculated between each data point during the deceleration
phase using Newton’s second law of motion:

HBF _t_ ð Þ ¼ _m_ ½ � _a t_ ð Þ�þ F _air t_ ð Þ (2)

where _m_ is the body mass of the participant and Fair is the air friction, which is influenced
by the frontal area of the participant (Af) (Morin et al., 2019):

Af ¼ � 0 _:_ 2025 � height \[0\] _\[:\]_ \[725\] � mass \[0\] _\[:\]_ \[425\] �

� 0 _:_ 266 (3)

Instantaneous HBP was calculated between each data point during the deceleration phase
using the product of HBF and _v_ :

HBP ¼ HBF � _v_ (4)

Instantaneous HBI was calculated between each data point during the deceleration phase
using change in momentum:

J tð Þ ¼ Mf � Mi (5)

where J is the impulse, Mf is the final momentum and Mi is the initial momentum.
Instantaneous momentum was calculated using the following equation:

Momentum tð Þ ¼ v � mass (6)

_**Statistical analysis**_

The mean ± SD was calculated for all radar-derived variables. Intra- and inter-day reliability
was calculated by determining the relative (intra-class correlation coefficient; ICC) and
absolute (coefficient of variation; CV%) reliability using the ‘consecutive pairwise’ Microsoft
Excel spreadsheet (Hopkins, 2015). This spreadsheet uses the ICC (3,1), which provides the
correlation expected between pairs of measurements in any two trials, when all participants
have performed the same two trials. CV was calculated from the TE and expressed as a %. The
thresholds used to interpret the ICC were taken from guidelines (Koo & Li, 2016) for reporting
ICC values: ≤0.49 = poor; 0.50 to 0.74 = moderate; 0.75 to 0.89 = good; ≥0.90 = excellent. The

8 D. J. HARPER ET AL.

CV% was interpreted using the following scale (McMahon et al., 2018): >15 poor; 10 to
15 moderate; 5 to 10 good; \<5 excellent. Overall reliability was interpreted by combining both
the ICC and the CV% scales as follows: ICC > 0.9 and CV% \<5 = excellent; ICC 0.75 to 0.9 and
CV% \<10 = good; ICC \< 0.75 or CV% >10 = moderate; ICC \<0.75 and CV% \<10 = poor. The
90% confidence intervals for all reliability results were also included.

To determine the sensitivity of each radar-derived variable the raw TE obtained from the
Microsoft Excel spreadsheet (Hopkins, 2015) was compared to the smallest worthwhile
change (SWC). SWC was calculated by multiplying the between-subject SD by 0.2 (SWC0.2)
, which is a small effect, or by 0.5 (SWC0.5), which is an alternative moderate effect. If the TE
was less than the SWC, the test variable was rated as ‘good’; if the TE was equal to the SWC
it was rated as ‘OK’, and if the TE was higher than the SWC it was rated ‘poor’.

**Results**

_**Intra-day reliability and sensitivity**_

The mean and standard deviation for all kinematic and kinetic variables connected with the

best two average deceleration trials on day 1 of testing are shown in Table 1. The corresponding
ICC and CV% values to determine intra-day reliability, and the TE and SWC to determine the
sensitivity of each test variable are also shown in Table 1. Of the kinematic variables only _V_ max
had excellent (ICC = 0.97, CV = 1.4%) overall intra-test reliability, and was able to detect the
SWC0.2. TT50% _V_ max (ICC = 0.76, CV = 8%), TTS (ICC = 0.82, CV = 5.3%), DTS (ICC = 0.76,
CV = 7.2%), DECave (ICC = 0.87, CV = 5.2%) and E-DECave (ICC = 0.76, CV = 8.8%) had
good overall intra-test reliability. However, only TTS and DECave demonstrated sufficient
sensitivity to detect the SWC0.5, with TT50% _V_ max, DTS and E-DECave rated as ‘OK’.

All kinetic variables apart from L-HBPave, HBFmax and HBPmax had good (ICC > 0.8,
CV \< 10%) overall reliability. However, only HBPave had sufficient sensitivity to detect
the SWC0.2. All kinetic variables were sensitive to detect SWC0.5.

_**Inter-day reliability and sensitivity**_

The mean and standard deviation for all kinematic and kinetic variables from day 1 and day 2
of testing are shown in Table 2. The corresponding ICC and CV% values to determine intertest reliability, and the TE and SWC to determine the sensitivity of each variable across days
are also shown in Table 2. Similar to intra-day reliability for the kinematic variables, only
_V_ max had excellent (ICC = 0.96, CV = 1.7%) overall inter-day reliability, and was able to detect
the SWC0.2. TTS (ICC = 0.45, CV = 8.2%), DECave (ICC = 0.73, CV = 8.0%) and DECmax
(ICC = 0.61, CV = 7.9%) had moderate overall inter-day reliability. All other kinematic
variables had poor (ICC = \<0.75, CV > 10%) inter-day reliability.

For the kinetic variables HBFave (ICC = 0.90, CV = 9.3%), HBPave (ICC = 0.93, CV = 8.9%)
and HBIave (ICC = 0.90, CV = 9.0%) had overall good inter-day reliability. However, only
HBPave and HBIave were sensitive to detect the SWC0.5. HBFmax (ICC = 0.89, CV = 8.2%),
HBPmax (ICC = 0.96, CV = 6.2%) and HBImax (ICC = 0.90, CV = 8.2%) also had good overall
inter-day reliability, and were sensitive enough to detect the SWC0.5. Both E-HBFave
(ICC = 0.89, CV = 12.2) and L-HBFave (ICC = 0.76, CV = 11.7) had moderate inter-day
reliability, and were sensitive enough to detect SWC0.5. Similarly, both E-HBIave (ICC = 0.87,

SPORTS BIOMECHANICS 9

10 D. J. HARPER ET AL.

SPORTS BIOMECHANICS 11

CV = 8.2%) and L-HBIave (ICC = 0.77, CV = 11.4%) had moderate inter-day reliability,
although only E-HBIave was sensitive to detect the SWC0.5.

**Discussion and implications**

To our knowledge, this is the first study to examine the intra- and inter-day reliability and
sensitivity of radar-derived kinematic and kinetic variables measured during a novel
maximal horizontal deceleration test. The major findings of this study are: (1) a number
of kinematic (i.e., TT50% _V_ max, TTS, DTS, DECave, E-DECave) and kinetic (i.e., HBFave,
HBPave, HBIave, HBImax) variables had good overall intra-day reliability, and were
sensitive to detect moderate changes in performance, (2) kinematic variables (TTS,
DECave and DECmax) had moderate overall inter-day reliability, and (3) only kinetic
variables (HBFave, HBPave, HBIave, HBFmax, HBPmax, and HBImax) had good overall interday reliability and were adequately sensitive to detect moderate changes in performance.
Therefore, the original study hypothesis can be rejected, since only kinetic variables had
good overall intra- and inter-day reliability, and were sufficiently sensitive to detect
small-to-moderate changes in horizontal deceleration ability.

Previous studies measuring deceleration performance have used either a COD (Hader
et al., 2016, 2015; Jones et al., 2017) or horizontal sprint acceleration-to-deceleration task
(Ashton & Jones, 2019; Cesar & Sigward, 2015, 2016; Graham-Smith et al., 2018; Harper
et al., 2018; Naylor & Greig, 2015). The use of a horizontal sprint acceleration to
deceleration task allows deceleration performance to be examined independently of
COD-imposed technical constraints. Furthermore, the deceleration phase during
a COD task typically occurs from sub-maximal sprinting velocities (Dos’Santos et al.,
2018; Hader et al., 2015), and subsequently may be unreflective of the deceleration
characteristics necessary to successfully decelerate from near-maximum sprint velocities.
Accordingly, during COD-related deceleration tasks, the deceleration challenge may not
be a valid representation of a performer’s maximal deceleration capacity.

Whilst a number of previous studies have used a horizontal sprint acceleration-todeceleration task to examine maximal deceleration capabilities, only one of these studies
examined the reliability and sensitivity of the measures obtained (Ashton & Jones, 2019).
Here, deceleration performance was measured using a laser device following 15 m sprint
acceleration and evaluated using the deceleration distance measured at 75%, 50%, 25%
and 0% of the participant’s 15 m horizontal sprint velocity. Based on their findings, the
authors subsequently suggested using total DTS (0% of 15 m velocity) to measure
deceleration ability. However, due to the higher average CV (10.52%) for this variable,
it was also recommended that further work to be conducted to establish a protocol that is
more sensitive to tracking changes in horizontal deceleration ability. It is likely, as
suggested by the authors of this study, that the high measurement variability, using
this protocol, was due to the start of the deceleration phase being defined as the velocity at
the 15 m mark. For instance, the average 15 m velocity was 5.39 m/s, which was much
lower than the average peak velocity (6.84 m/s) recorded during the test. This finding
implies that participants had already started to decelerate prior to the 15-m mark. To
overcome this problem, in the current study, we defined the start of the deceleration
phase as the time point immediately following Vmax achieved during the 20 m sprint.
This definition has previously been used to quantify deceleration ability using a laser

12 D. J. HARPER ET AL.

device (Graham-Smith et al., 2018). Furthermore, in order to reduce the likelihood of
participants commencing deceleration prior to the 20-m mark, and to ensure better
precision and consistency in when the deceleration phase commenced, any 20 m time
that was 5% greater than the participants 20 m linear sprint time (without a maximal
deceleration) was considered an unsuccessful trial. Using these criteria, the average
distance at which deceleration commenced was 17.2 m, with excellent (3.7%) to good
(5.9%) consistency demonstrated between trials and between days, respectively.
Therefore, these findings demonstrate that by using Vmax to denote the start of decelera­
tion, and by regulating the time at which deceleration commenced, consistent distances
at which deceleration commences can be obtained.

The DTS variable in the present study had good overall intra-day reliability
(ICC = 0.76, CV = 7.2%), but poor inter-day reliability (ICC = 0.45, CV = 10.8%). The
kinematic variable with the best intra- and inter-day reliability and sensitivity was
DECave. The overall reliability of this variable was good (ICC = 0.87, CV = 5.2%) to
moderate (ICC = 0.73, CV = 8.0%), with the sensitivity to detect small changes in
performance rated as ‘good’, for intra-day reliability. These findings are similar to
those of Varley et al. (2012), who reported a CV of 6% for DECave when the deceleration
phase was measured using a 10 Hz global positioning system during a horizontal running
task performed from velocities ranging between 5 and 8 m/s. In the present study,
decelerations commenced from a much narrower velocity range (7.17 to 7.36 m/s) and
were measured using a higher sampling rate (47 Hz). In the study by Varley et al. (2012)
the rate of deceleration was not reported. Therefore, the similar CV% found between
these studies is likely due to the higher rates of deceleration (−4.36 to −4.44 m/s \[2\] )
performed in the present study. Nonetheless, based on the findings of the present study,
DECave is the kinematic variable of choice when monitoring SWC in maximal horizontal
deceleration ability.

In sprint acceleration research, laser, radar and video devices are commonly used, in
conjunction with using simple computational methods, to provide advanced insights into
the mechanical (kinetic) determinants of sprint acceleration performance (Morin et al.,
2019; Romero-Franco et al., 2017; Simperingham et al., 2016). Such an approach provides
a more in-depth understanding of the underpinning mechanical features determining
maximal sprint acceleration performance and can be subsequently used to inform
individualised and specific training prescriptions (Morin & Samozino, 2016). Despite
widespread use in sprint acceleration profiling, this is the first study to use instantaneous
horizontal velocity-time data to estimate the horizontal braking force (HBF), power
(HBP) and impulse (HBI) during a maximal horizontal deceleration task. The findings
of this study show that, when averaged across the entire deceleration phase, HBF, HBP
and HBI had good overall intra-day (ICC = 0.95 to 0.96, CV = 5.1% to 5.7%) and interday reliability (ICC = 0.90 to 0.93, CV = 8.9% to 9.3%), and were sufficiently sensitive to
detect moderate changes in horizontal deceleration ability.

Subsequently, as is the case with horizontal sprint acceleration profiling, coaches and
sport science professionals can productively use these mechanical outputs to obtain more
in-depth understanding of their athlete’s deceleration capabilities. In a different athletic
context, such as rugby and American Football, within which players operating in different
positions typically have widely varying body masses, changes in whole-body momentum—
referred to in this study as the horizontal braking impulse (HBI)—could provide

SPORTS BIOMECHANICS 13

particularly insightful information. Especially since these players will inevitably have to
generate higher braking forces in order to reduce higher whole-body momentums. Future
research should investigate the influence of these mechanical variables on maximal decel­
eration performance capacities (e.g., average deceleration), and compare the validity of
these variables to direct measures obtained from embedded force platforms.

In order to obtain a more thorough evaluation of deceleration performance, the
deceleration velocity profile was sub-divided into ‘early’ and ‘late’ deceleration phases.
It has previously been shown in walking gait termination that decelerating can involve
distinct phases: ‘preparatory brake’, ‘fast brake’ and ‘final brake’ (Jian et al., 1993). The
‘fast brake’ period comprising a rapid reduction in velocity with greater braking forces,
whereas the ‘final brake’ comprised a small reduction in velocity, with the main goal
being to stabilise the centre of mass above the base of support. By examining both the
early and late deceleration phases, it is subsequently possible to calculate a horizontal
deceleration or braking-ratio, which could allow further identification of individualspecific deceleration strategies and training needs. In the present study, only HBF and
HBI variables had good overall intra-day reliability (ICC = 0.84 to 0.91, CV = 8.7% to
9.6%), and were sensitive enough to detect moderate changes in the early and late
deceleration phases. Furthermore, both of these variables had moderate overall interday reliability (ICC = 0.76 to 0.87, CV = 11.4% to 12.2%) and were able to detect
moderate changes in the early deceleration phase. Subsequently, for the purpose of
monitoring the early and late deceleration phases, the kinetic variables HBF and HBI
are recommended. Further research is required to investigate the importance of the early
and late deceleration phases on overall deceleration performance, and the neuromuscular
performance characteristics that may contribute to superior early and late deceleration
performance.

This study has limitations similar to those highlighted in the previous work exam­
ining the reliability of horizontal force-velocity power profiling during short sprint
accelerations (Simperingham et al., 2019). Specifically, raw data captured from the
radar were filtered using the manufacturers own proprietary software. Therefore, it is
possible that alternative post-processing methods may be more applicable. For exam­
ple, analysing the raw data points using a rolling average across different time frames
(e.g., 0.2, 0.3 s) or by filtering using different cut-off frequencies. Although this study
attempted to control the start and end of the deceleration phase, it is possible that
different approaches may lead to improved reliability and sensitivity. For example,
using a ‘start’ and ‘end’ of deceleration phase criteria that is based on a deceleration
threshold, such as, when deceleration is below and above −0.2 m/s \[2, \] respectively.
Therefore, future research should investigate the reliability and sensitivity of different
criteria that could be used to define the ‘start’ and ‘end’ of the deceleration phase.
Furthermore, the radar device used in this study sampled at a rate of 47 Hz. Other
devices, such as lasers, capable of sampling at higher frequencies, may prove more
reliable and sensitive to deceleration data. Additionally, low-cost, user-friendly highspeed video (capable of sampling at 240 Hz), as used to profile sprint acceleration
performance and the associated mechanical outputs (Romero-Franco et al., 2017),
could be used to simultaneously gain important deceleration kinematic and kinetic
data. The simple computational methods used to calculate mechanical outputs have not
been validated and, subsequently, may therefore under- or over-estimate the actual

14 D. J. HARPER ET AL.

values reported. The participants used in this study were all young University sport
athletes. Research to investigate whether more experienced and higher performing (and
perhaps less variable) athletes demonstrate a greater level of assessment consistency is
merited. Also the horizontal acceleration-to-deceleration task used in this study was
performed after one familiarisation session and on an artificial indoor surface.
Reliability and sensitivity of the data may, subsequently, be further improved when
performed on sport-specific surfaces, or with more than one familiarisation session.

Finally, although the horizontal deceleration test used in the current study protocol
requires multiple high-intensity efforts, it replicates common team sport training tasks.
Therefore, practitioners could implement this horizontal deceleration test into routine
athlete monitoring systems, whilst also gaining performance and injury risk reduction
benefits. Furthermore, simple adjustments to this deceleration test protocol—for exam­
ple, using different acceleration distances (5, 10 and 15 m) and prescribed distance
targets, similar to those commonly used in COD tests (such as the 505), could provide
an adaptive means to gather information on a diversity of deceleration tasks and abilities.
Clearly, however, future research is needed to determine if the deceleration abilities
assessed at lower horizontal velocities or momentums are reflective of the deceleration
abilities assessed at higher horizontal velocities or momentums.

**Conclusions**

Using a novel maximal horizontal deceleration test, a number of radar-derived kinematic
and kinetic variables had good intra-day reliability and were sufficiently sensitive to
detect small-to-moderate worthwhile changes in deceleration performance. Only kinetic
variables had good inter-day reliability and were adequately able to detect moderate
worthwhile changes in deceleration performance after a single familiarisation session.
Consequently, coaches and sport science professionals can use mechanical outputs
obtained from simple computational methods to profile an individual’s maximal hor­
izontal deceleration performance. In the future, these approaches may provide insights
illuminating the neuromuscular capabilities needed to decelerate maximally.

**Acknowledgments**

The authors would like to acknowledge the study participants and all the research assistants
involved in the data collection process.

**Disclosure statement**

No potential conflict of interest was reported by the author(s).

**ORCID**

Damian J. Harper <http://orcid.org/0000-0002-5430-1541>
Jean-Benoit Morin <http://orcid.org/0000-0003-3808-6762>
Christopher Carling <http://orcid.org/0000-0002-7456-3493>

SPORTS BIOMECHANICS 15

John Kiely <http://orcid.org/0000-0001-9817-0224>

**References**

Ashton, J., & Jones, P. (2019). The reliability of using a laser device to assess deceleration ability.

_Sports_, _7_ [, 191. doi:10.3390/sports7080191](https://doi.org/10.3390/sports7080191)
Cesar, G. M., & Sigward, S. M. (2015). Dynamic stability during running gait termination:

Differences in strategies between children and adults to control forward momentum. _Human_
_Movement Science_, _43_ [, 138–145. doi:10.1016/j.humov.2015.08.005](https://doi.org/10.1016/j.humov.2015.08.005)
Cesar, G. M., & Sigward, S. M. (2016). Dynamic stability during running gait termination:

Predictors for successful control of forward momentum in children and adults. _Human_
_Movement Science_, _48_ [, 37–43. doi:10.1016/j.humov.2016.03.014](https://doi.org/10.1016/j.humov.2016.03.014)
Colyer, S. L., Nagahara, R., Takai, Y., & Salo, A. I. T. (2018). How sprinters accelerate beyond the

velocity plateau of soccer players: Waveform analysis of ground reaction forces. _Scandinavian_
_Journal of Medicine & Science in Sports_, _28_ [, 2527–2535. doi:10.1111/sms.13302](https://doi.org/10.1111/sms.13302)
Cronin, J. B., & Templeton, R. L. (2008). Timing light height affects sprint times. _Journal of_

_Strength and Conditioning Research_, _22_ [, 318–320. doi:10.1519/JSC.0b013e31815fa3d3](https://doi.org/10.1519/JSC.0b013e31815fa3d3)
Cross, M. R., Brughelli, M., Samozino, P., & Morin, J.-B. (2017). Methods of power-force-velocity

profiling during sprint running: A narrative review. _Sports Medicine_, _47_, 1255–1269.
[doi:10.1007/s40279-016-0653-3](https://doi.org/10.1007/s40279-016-0653-3)
Dalen, T., Ingebrigtsen, J., Ettema, G., Hjelde, G. H., & Wisløff, U. (2016). Player load, acceleration,

and deceleration during forty-five competitive matches of elite soccer. _Journal of Strength and_
_Conditioning Research_, _30_ [, 351–359. doi:10.1519/JSC.0000000000001063](https://doi.org/10.1519/JSC.0000000000001063)
De Hoyo, M., Cohen, D. D., Sañudo, B., Carrasco, L., Álvarez-Mesa, A., Del Ojo, J. J., Domínguez
Cobo, S., Mañas, V., & Otero-Esquina, C. (2016). Influence of football match time-motion
parameters on recovery time course of muscle damage and jump ability. _Journal of Sports_
_Sciences_, _34_ [, 1363–1370. doi:10.1080/02640414.2016.1150603](https://doi.org/10.1080/02640414.2016.1150603)
Dos’Santos, T., Thomas, C., Comfort, P., & Jones, P. A. (2018). The effect of angle and velocity on

change of direction biomechanics: An angle-velocity trade-off. _Sports Medicine_, _48_, 2235–2253.
[doi:10.1007/s40279-018-0968-3](https://doi.org/10.1007/s40279-018-0968-3)
Graham-Smith, P., Rumpf, M., & Jones, P. (2018). Assessment of deceleration ability and relation­

ship to approach speed and eccentric strength. _ISBS-Conference Proceedings Archive_, _36_, 8.
Hader, K., Palazzi, D., & Buchheit, M. (2015). Change of direction speed in soccer: How much

braking is enough? _Kinesiology_, _47_, 67–74.
Hader, K., Mendez-Villanueva, A., Palazzi, D., Ahmaidi, S., & Buchheit, M. (2016). Metabolic

power requirement of change of direction speed in young soccer players: Not all is what it
seems. _PLoS ONE_, _11_ [, e0149839. doi:10.1371/journal.pone.0149839](https://doi.org/10.1371/journal.pone.0149839)
Harper, D. J., Jordan, A. R., & Kiely, J. (2018). Relationships between eccentric and concentric knee

strength capacities and maximal linear deceleration ability in male academy soccer players.
_Journal of Strength and Conditioning Research_ [. doi:10.1519/JSC.0000000000002739](https://doi.org/10.1519/JSC.0000000000002739)
Harper, D. J., & Kiely, J. (2018). Damaging nature of decelerations: Do we adequately prepare

players? _BMJ Open Sport & Exercise Medicine_, _4_ [, e000379. doi:10.1136/bmjsem-2018-000379](https://doi.org/10.1136/bmjsem-2018-000379)
Harper, D. J., Carling, C., & Kiely, J. (2019). High-intensity acceleration and deceleration demands

in elite team sports competitive match play: A systematic review and meta-analysis of observa­
tional studies. _Sports Medicine_, _49_ [, 1923–1947. doi:10.1007/s40279-019-01170-1](https://doi.org/10.1007/s40279-019-01170-1)
Hopkins, W. G. (2015). Spreadsheets for analysis of validity and reliability. _Sportscience_, _19_, 36–44.
Howatson, G., & Milak, A. (2009). Exercise-induced muscle damage following a bout of sport

specific repeated sprints. _Journal of Strength and Conditioning Research_, _23_, 2419–2424.
[doi:10.1519/JSC.0b013e3181bac52e](https://doi.org/10.1519/JSC.0b013e3181bac52e)
Jian, Y., Winter, D., Ishac, M., & Gilchrist, L. (1993). Trajectory of the body COG and COP during

initiation and termination of gait. _Gait & Posture_, _1_ [, 9–22. doi:10.1016/0966-6362(93)90038-3](<https://doi.org/10.1016/0966-6362(93)90038-3>)

16 D. J. HARPER ET AL.

Jones, P., Thomas, C., Dos’Santos, T., McMahon, J., & Graham-Smith, P. (2017). The role of

eccentric strength in 180° turns in female soccer players. _Sports_, _5_ [, 42. doi:10.3390/](https://doi.org/10.3390/sports5020042)
[sports5020042](https://doi.org/10.3390/sports5020042)
Keane, K. M., Salicki, R., Goodall, S., Thomas, K., & Howatson, G. (2015). Muscle damage

response in female collegiate athletes after repeated sprint activity. _Journal of Strength and_
_Conditioning Research_, _29_ [, 2802–2807. doi:10.1519/JSC.0000000000000961](https://doi.org/10.1519/JSC.0000000000000961)
Koo, T. K., & Li, M. Y. (2016). A guideline of selecting and reporting intraclass correlation

coefficients for reliability research. _Journal of Chiropractic Medicine_, _15_ [, 155–163. doi:10.1016/](https://doi.org/10.1016/j.jcm.2016.02.012)
[j.jcm.2016.02.012](https://doi.org/10.1016/j.jcm.2016.02.012)
Loturco, I., Pereira, L. A., Freitas, T. T., Alcaraz, P. E., Zanetti, V., Bishop, C., & Jeffreys, I. (2019).

Maximum acceleration performance of professional soccer players in linear sprints: Is there
a direct connection with change-of-direction ability? _PLoS ONE_, _14_ [, e0216806. doi:10.1371/](https://doi.org/10.1371/journal.pone.0216806)
[journal.pone.0216806](https://doi.org/10.1371/journal.pone.0216806)
Martín-García, A., Casamichana, D., Gómez Díaz, A., Cos, F., & Gabbett, T. J. (2018). Positional

differences in the most demanding passages of play in football competition. _Journal of Sports_
_Science & Medicine_, _17_, 563–570.
McMahon, J., Lake, J., & Comfort, P. (2018). Reliability of and relationship between flight time to

contraction time ratio and reactive strength index modified. _Sports_, _6_ [, 81. doi:10.3390/](https://doi.org/10.3390/sports6030081)
[sports6030081](https://doi.org/10.3390/sports6030081)
Morin, J.-B., Edouard, P., & Samozino, P. (2011). Technical ability of force application as

a determinant factor of sprint performance. _Medicine and Science in Sports and Exercise_, _43_,
[1680–1688. doi:10.1249/MSS.0b013e318216ea37](https://doi.org/10.1249/MSS.0b013e318216ea37)
Morin, J.-B., Gimenez, P., Edouard, P., Arnal, P., Jiménez-Reyes, P., Samozino, P., Brughelli, M., &

Mendiguchia, J. (2015). Sprint acceleration mechanics: The major role of hamstrings in hor­
izontal force production. _Frontiers in Physiology_, _6_ [, 404. doi:10.3389/fphys.2015.00404](https://doi.org/10.3389/fphys.2015.00404)
Morin, J.-B., & Samozino, P. (2016). Interpreting power-force-velocity profiles for individualized

and specific training. _International Journal of Sports Physiology and Performance_, _11_, 267–272.
[doi:10.1123/ijspp.2015-0638](https://doi.org/10.1123/ijspp.2015-0638)
Morin, J.-B., Samozino, P., Murata, M., Cross, M. R., & Nagahara, R. (2019). A simple method for

computing sprint acceleration kinetics from running velocity data: Replication study with
improved design. _Journal of Biomechanics_, _94_ [, 82–87. doi:10.1016/j.jbiomech.2019.07.020](https://doi.org/10.1016/j.jbiomech.2019.07.020)
Nagahara, R., Botter, A., Rejc, E., Koido, M., Shimizu, T., Samozino, P., & Morin, J.-B. (2017).

Concurrent validity of GPS for deriving mechanical properties of sprint acceleration.
_International Journal of Sports Physiology and Performance_, _12_ [, 129–132. doi:10.1123/](https://doi.org/10.1123/ijspp.2015-0566)
[ijspp.2015-0566](https://doi.org/10.1123/ijspp.2015-0566)
Naylor, J., & Greig, M. (2015). A hierarchical model of factors influencing a battery of agility tests.

_The Journal of Sports Medicine and Physical Fitness_, _55_, 1329–1335.
Romero-Franco, N., Jiménez-Reyes, P., Castaño-Zambudio, A., Capelo-Ramírez, F., Rodríguez
Juan, J. J., González-Hernández, J., Toscano-Bendala, F. J., Cuadrado-Peñafiel, V., & BalsalobreFernández, C. (2017). Sprint performance and mechanical outputs computed with an iPhone
app: Comparison with existing reference methods. _European Journal of Sport Science_, _17_,
[386–392. doi:10.1080/17461391.2016.1249031](https://doi.org/10.1080/17461391.2016.1249031)
Russell, M., Sparkes, W., Northeast, J., Cook, C. J., Love, T. D., Bracken, R. M., & Kilduff, L. P.

(2016). Changes in acceleration and deceleration capacity throughout professional soccer
match-play. _Journal of Strength and Conditioning Research_, _30_ [, 2839–2844. doi:10.1519/](https://doi.org/10.1519/JSC.0000000000000805)
[JSC.0000000000000805](https://doi.org/10.1519/JSC.0000000000000805)
Simperingham, K. D., Cronin, J. B., & Ross, A. (2016). Advances in sprint acceleration profiling for

field-based team-sport athletes: Utility, reliability, validity and limitations. _Sports Medicine_, _46_,
[1619–1645. doi:10.1007/s40279-016-0508-y](https://doi.org/10.1007/s40279-016-0508-y)
Simperingham, K. D., Cronin, J. B., Pearson, S. N., & Ross, A. (2019). Reliability of horizontal

force-velocity-power profiling during short sprint-running accelerations using radar
technology. _Sports Biomechanics_, _18_ [, 88–99. doi:10.1080/14763141.2017.1386707](https://doi.org/10.1080/14763141.2017.1386707)

SPORTS BIOMECHANICS 17

Tierney, P. J., Young, A., Clarke, N. D., & Duncan, M. J. (2016). Match play demands of 11 versus

11 professional football using global positioning system tracking: Variations across common
playing formations. _Human Movement Science_, _49_ [, 1–8. doi:10.1016/j.humov.2016.05.007](https://doi.org/10.1016/j.humov.2016.05.007)
Varley, M. C., Fairweather, I. H., & Aughey, R. J. (2012). Validity and reliability of GPS for

measuring instantaneous velocity during acceleration, deceleration, and constant motion.
_Journal of Sports Sciences_, _30_ [, 121–127. doi:10.1080/02640414.2011.627941](https://doi.org/10.1080/02640414.2011.627941)
Verheul, J., Nedergaard, N. J., Pogson, M., Lisboa, P., Gregson, W., Vanrenterghem, J., &

Robinson, M. A. (2019). Biomechanical loading during running: Can a two mass-springdamper model be used to evaluate ground reaction forces for high-intensity tasks? _Sports_
_Biomechanics_ [. doi:10.1080/14763141.2019.1584238](https://doi.org/10.1080/14763141.2019.1584238)
